pub struct ConstI8<const N: i8>;Trait Implementations
Sourceimpl<const N: i8> Cuisiner for ConstI8<N>
impl<const N: i8> Cuisiner for ConstI8<N>
type Raw<B: ByteOrder> = i8
Sourcefn try_from_raw<B: ByteOrder>(raw: Self::Raw<B>) -> Result<Self, CuisinerError>
fn try_from_raw<B: ByteOrder>(raw: Self::Raw<B>) -> Result<Self, CuisinerError>
Attempt to convert this value from a raw value.
Sourcefn try_to_raw<B: ByteOrder>(self) -> Result<Self::Raw<B>, CuisinerError>
fn try_to_raw<B: ByteOrder>(self) -> Result<Self::Raw<B>, CuisinerError>
Attempt to convert this value into the raw value.
Sourcefn from_bytes<B: ByteOrder>(bytes: &[u8]) -> Result<Self, CuisinerError>
fn from_bytes<B: ByteOrder>(bytes: &[u8]) -> Result<Self, CuisinerError>
Read the provided bytes and attempt to parse out the type.
impl<const N: i8> Eq for ConstI8<N>
impl<const N: i8> StructuralPartialEq for ConstI8<N>